package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@(!`0````````````,`"``!````L!X```````!``````````""X````
M````!P``@$``.``*`$``'P`>``8````%````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```#`IP``````
M`,"G````````P*<````````/``````````\``````````0`````````#``!P
M!````'`"````````<`(```````!P`@```````!@`````````&``````````(
M``````````$````%````````````````````````````````````]*<`````
M``#TIP```````````0```````0````8```#HKP```````.BO`0``````Z*\!
M``````"8`P```````-@3```````````!```````"````!````$`$````````
M0`0```````!`!````````*`"````````H`(````````(``````````0````$
M````&`0````````8!````````!@$````````)``````````D``````````0`
M````````!`````0```#4IP```````-2G````````U*<````````@````````
M`"``````````!`````````!2Y71D!````.BO````````Z*\!``````#HKP$`
M`````!@`````````&``````````!````````````````````````````````
M``````````````````````````````````````````@```````````!``@("
M``$```````````$``````````2@```````#V!P"R````````````````````
M```````P,`(```````$H````````````````````````````````````````
M,#`"```````!*````````````````````````````````````````#`P`@``
M`````2@````````$``"R```````````````````````````P,`(```````$H
M````````/``!L@``````````````````````````,#`"```````!*```````
M`/S___,``````````````````````````#`P`@```````2@```````"$``"R
M```````````````````````````P,`(```````$H````````<``_L@``````
M````````````````````,#`"```````!*```````````````````````````
M`````````````#`P`@```````2@```````````"P````````````````````
M```````P,`(```````0````4`````P```$=.50"R>SPOQ,^[D(UU#]PMTT_Q
MU4=C_@`````!`````````$($`````````0````````!2!`````````$`````
M````700````````!`````````&<$`````````0````````")!`````````$`
M````````K`0````````!`````````+0$````````#`````````"0&P``````
M``T`````````(&8````````9`````````.BO`0``````&P`````````(````
M`````!H`````````\*\!```````<``````````@`````````!`````````#@
M!@````````4`````````6!0````````&`````````"`*````````"@``````
M``!7!0````````L`````````&``````````U``!P`````-"J`0``````%0``
M``````````````````,`````````0+`!```````1`````````$`;````````
M$@````````!0`````````!,`````````$``````````!``!P``````$`````
M````!0``<``````"``````````8``'`````````````````*``!P`````!P`
M````````$0``<`````!M`````````!(``'``````'@`````````3``!P````
M`"(`````````'@`````````(`````````/O__V\``````0``"`````#^__]O
M`````)`:````````____;P`````#`````````/#__V\`````L!D`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!A````;0```````````````````"H``````````````#(`````````
M/0```"<```!/`````````$D```!0````#@````````!8````&0````,````L
M````"0```!$````^````+P``````````````60```!4````F````````````
M```A````'````#\````P`````````!8````@`````````#8`````````-```
M``````!(````%````!(````D`````````&H````:`````````$<```!6````
M```````````8````2@```#H```!&``````````````!A`````````%,`````
M````'P``````````````9````"4````H````+0```$4````I````````````
M```"````"P```$$```!G````&P```!`````U`````````"(````>````````
M```````3````%P````````!`````'0```$,````C````,0```#L`````````
M````````````````````````````````9@```````````````````&@`````
M``````````````!2````90````H````-``````````````!$````!```````
M``````````````````!?````6P```````````````````%X````W````/```
M```````S````3````"X``````````````"L``````````````&````!L````
M`````%$`````````.0```$(```!+`````````#@```!4``````````````!C
M````3@`````````````````````````/``````````@``````````````&(`
M```,````30````````!I`````````%P``````````````%H`````````````
M````````````50```%<```````````````````````````````````!=````
M:P``````````````!0````````````````````<`````````````````````
M````!@``````````````````````````````````````````````````````
M``````````````,`"P"0&P``````````````````+````!(`#``X8@``````
M``@`````````[@0``!(`#`!`0P```````!@``````````0```!,`\?\!````
M````````````````#@4``"$`%@``L`$`````````````````H@0``!$`````
M````````````````````/@(``!(`#``@2P```````%@`````````(@0``!(`
M#`!08````````-0`````````T`0``!``&0"`LP$`````````````````-@``
M`!(`#@`@9@``````````````````_P0``!(`#```1@```````"P`````````
M90,``!(`#``P1@```````(@!````````-P,``!(`#`!H30```````!@.````
M````#`4``!$`%@``L`$`````````````````DP0``!$`#P!09@````````0`
M````````R00``!``%@``L`$`````````````````[@$``!(`#``X0@``````
M``0!````````$@```!$`%P`PL`$`````````````````'````!(`#`"080``
M`````*@`````````SP,``!$`%@`@L`$```````@`````````Z00``!``&@#`
MPP$`````````````````X`(``!(`#`"X1P```````+`"````````UP0``!``
M&@"`LP$`````````````````L0$``!(`#`!@00```````%@`````````20``
M`!(`#`#0&P```````-0"````````&04``!(`#`"P'@``````````````````
MA0(``!(`#`!80P```````*@"````````IP(``!(`#`!X2P```````/`!````
M````D@(``!(`#`!H2@```````+@`````````P@0``!``#`#0&P``````````
M````````XP0``!``&@"`LP$`````````````````LP$``!(`"P"0&P``````
M````````````R@$``!(`#`"`6P```````-`$````````&0$``!(`````9@``
M````````````````^````!(```#P90``````````````````"@$``!(```#@
M90``````````````````TP(``!(```#090``````````````````5P$``!(`
M``#`90``````````````````0P$``!(```"P90``````````````````)P$`
M`!(```"@90``````````````````I`0``!$`````````````````````````
MV0```!(```"090``````````````````>0```"``````````````````````
M````=P(``!(```"`90````````````````````$``!(```!P90``````````
M````````&00``!(```!@90``````````````````>0$``!(```!090``````
M````````````H@```"``````````````````````````DP,``!(`````````
M````````````````_0(``!(```!`90``````````````````"P(``!(````P
M90``````````````````8@$``!(````@90``````````````````N0$``!(`
M```090``````````````````V0,``!(`````90``````````````````(@(`
M`!(```#P9```````````````````60,``!(```#@9```````````````````
M_`,``!(```#09```````````````````<@$``!(```#`9```````````````
M````7P(``!(```"P9```````````````````@`,``!(`````````````````
M````````&0(``!(```"@9```````````````````60(``!(```"09```````
M````````````V0(``!(```"`9```````````````````I@$``!(```!P9```
M````````````````1`,``!(```!@9```````````````````'0,``!(```!0
M9```````````````````H`(``!(```!`9```````````````````/````!(`
M```P9```````````````````X0```!(````@9```````````````````<0,`
M`!(````09```````````````````!`(``!(`````9```````````````````
M+@0``!$`````````````````````````/00``!(```#P8P``````````````
M````3@```"(`````````````````````````Q@(``!(```#@8P``````````
M````````[0(``!(```#08P``````````````````R`,``!(```#`8P``````
M````````````Z````!(```"P8P``````````````````O`,``!(```"@8P``
M````````````````X`$``!(```"08P``````````````````N0(``!(```"`
M8P``````````````````=P0``!(```!P8P``````````````````L0,``!(`
M``!@8P``````````````````"P,``!(```!08P``````````````````B`$`
M`!(```!`8P``````````````````:0$``!(````P8P``````````````````
MI`,``!$`````````````````````````Y`,``!(````@8P``````````````
M````,0$``!(````08P``````````````````.`$``!$`````````````````
M````````,`(``!(`````8P``````````````````R````!(```#P8@``````
M````````````\@,``!(```#@8@``````````````````"@0``!(```#08@``
M````````````````$P$``!(```#`8@``````````````````E@$``!(`````
M````````````````````*0,``!(```"P8@``````````````````M@```!$`
M````````````````````````YP$``!(```"@8@``````````````````]P,`
M`!(```"08@``````````````````\````!(```"`8@``````````````````
M<`(``!$`````````````````````````4`(``!(```!P8@``````````````
M````70```"``````````````````````````P0(``!(```!@8@``````````
M````````DP```"(`````````````````````````$@(``!(```!08@``````
M````````````-P(``!(```!`8@```````````````````%]$64Y!34E#7TQ)
M3DM)3D<`7U]23$1?34%0`%]?;&EB8U]C<W5?:6YI=`!?7VQI8F-?8W-U7V9I
M;FD`7U]L:6)C7W-T87)T7VUA:6X`7U]G;6]N7W-T87)T7U\`7TE435]D97)E
M9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`
M7U]C>&%?9FEN86QI>F4`7TIV7U)E9VES=&5R0VQA<W-E<P!?7W-T86-K7V-H
M:U]G=6%R9`!?7W-T86-K7V-H:U]F86EL`'-T<FYC;7``<W1R;&5N`')E86QL
M;V,`;65M;6]V90!O<&5N9&ER`')E861D:7(V-`!C;&]S961I<@!R;61I<@!?
M7W-P<FEN=&9?8VAK`%]?>'-T870V-`!U;FQI;FL`4$Q?=&AR7VME>0!P=&AR
M96%D7V=E='-P96-I9FEC`%]?;'AS=&%T-C0`86-C97-S`')E861L:6YK`&UE
M;6-H<@!097)L7W-V7W-E='!V;@!097)L7W-V7W-E='!V`&)O;W1?1'EN84QO
M861E<@!097)L7VYE=UA3`'AS7VEN:70`4&5R;%]N97=84U]F;&%G<P!84U])
M;G1E<FYA;'-?4$%27T)/3U0`9V5T<&ED`&UE;6-P>0!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`<W1R8VAR`'-T<G1O:P!S=')C;7``7U]S=')D=7``7U]S=')N
M8W!Y7V-H:P!G971U:60`<W1R<W1R`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W
M=6ED`&UK9&ER`%]?97)R;F]?;&]C871I;VX`<W1D97)R`%]?9G!R:6YT9E]C
M:&L`<&%R7V9I;F1P<F]G`'!A<E]E;G9?8VQE86X`;W!E;C8T`'!A<E]S971U
M<%]L:6)P871H`&QS965K-C0`<F5A9`!?7VUE;6-P>5]C:&L`8VQO<V4`;65M
M<V5T`'!A<E]I;FET7V5N=@!097)L7V=V7V9E=&-H<'8`4&5R;%]A=E]F971C
M:`!097)L7W-V7S)P=E]F;&%G<P!097)L7V=E=%]S=@!097)L7V%V7W-H:69T
M`'!A<E]M:W1M<&1I<@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VUG7W-E
M=`!P87)?9&ER;F%M90!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]U;FQO
M8VL`4&5R;%]A=&9O<FM?;&]C:P!03%]D;U]U;F1U;7``<&5R;%]A;&QO8P!0
M97)L7W-A9F5S>7-M86QL;V,`;7E?<&%R7W!L`'!E<FQ?<&%R<V4`<&5R;%]D
M97-T<G5C=`!P97)L7V9R964`4&5R;%]S>7-?=&5R;0!P97)L7V-O;G-T<G5C
M=`!P97)L7W)U;@!P87)?8VQE86YU<`!03%]M96UO<GE?=W)A<`!E>&ET`&QI
M8G!E<FPN<V\N-2XR-`!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L:6)P=&AR96%D
M+G-O+C``7U]R96=I<W1E<E]A=&9O<FL`;&EB8RYS;RXV`%])3U]S=&1I;E]U
M<V5D`%]?96YV:7)O;@!L9"YS;RXQ`&QI8F-R>7!T+G-O+C$`7V9T97AT`%]F
M9&%T80!?961A=&$`7U]B<W-?<W1A<G0`7V9B<W,`7V5N9`!P87)?8W5R<F5N
M=%]E>&5C`'!A<E]B87-E;F%M90!?7V1A=&%?<W1A<G0`7U]S=&%R=`!'3$E"
M0U\R+C0`1TQ)0D-?,BXR`$=,24)#7S(N,`!'3$E"0U\R+C,N-`!'3$E"0U\R
M+C,N,@````````$``0`!``$``@`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`)``(``@`$``,`!``#``(`
M`@````D``P```````````````@`"```````)```````"``0````"``(``@``
M```````(``(``@````(````"````"0````(``@````(`"``'``````````(`
M``````(````"``8```````(```````4``@`"``(``@`"````!``#``(``@``
M```````!``$`K`0``!`````@````%&EI#0``!0`A!0````````$``@!G!```
M$````#`````2:6D-```(`"L%```0````$&EI#0``!``U!0````````$`!0")
M!```$`````````!T&6D)```)`#\%```0````<AEI"0``!P!+!0``$````!1I
M:0T```8`(04``!`````2:6D-```#`"L%```0````$&EI#0```@`U!0``````
M``````````````````````#HKP$``````````````!(#\*\!````````````
M```2`R"P`0``````````````$@-XLP$``````````````!(#\/^]9P``O/\"
M`!P\+>"9`P@`O_^@%)QG,(*"WP0`0!``````,(*9WPGX(`,`````"`"_WP``
MO-\(`.`#$`"]9Y#_O6=@`+S_`@`</"W@F0-@%)QG,`"P__""D-]H`+__$(*9
MWU@`M?]0`+3_2`"S_T``LO\X`+'_```"WA``I?\(`*;_'`"DKP@`IF<0`*5G
M'`"D9R@`HO\)^"`#`````,"!AM]H@83?L("9WSP1$00E*,``F(*"WP``0I!F
M`$`0>(*9W[""D=\8@9G?"?@@`P``)(X``"2.F@5#D!B!F=\"`&,T"?@@`YH%
M0Z`<`*2/F@5%D`$``R0%`(0D?!\#``$`I30K&(,`;0!@$)H%1:!8@IG?"?@@
M`_@@!``0`*7?N("$WP``H]P``(?<``!#_%"`@]\<`*:/<&IC9`@`0_Q0@(/?
M.("(WWAJ8V08`$/\.("#WQ``1_P"`,0H!``')`0`R228PP+]#`"`%*##9ZP(
M`*5D!0`#)"4X(`$```````"HW/@@`P`M($0``0!C)/C_B/SZ_V<4"`"E9#B`
MD=]0@(7?D(&9W_A("0"PPR3>+4A)`"5````E.$```P#&)+A!I60)^"`#^/\@
M_3``0!`EF$``H(*9W[##)-Y0@)+?"?@@`R0`M&=0@(3?,#A29B4H@`(ER$`"
MJ081!$!GA&0H`$`0.("5W\B"F=\)^"`#L,,DWJB!F=\)^"`#`````"@`I-\`
M``/>-`"#%"408`)H`+_?8`"\WU@`M=]0`+3?2`"SWT``LM\X`+'?,`"PWP@`
MX`-P`+UG"?@@`P`````X@(/?*`!`$+##8OS0@IG?)2!```GX(`.P@I'?&(&9
MWPGX(`,``"2.C_\`$)T)0*!0@9G?"?@@`[##)-[-_P`0)9A``*C#I-X*`(`0
MP("9WX,0$00`````U/\`$,B"F=]0@(3?((*%W^B!F=\)^"`#:&J$9%"`A-\E
M*(`")<A``F\&$03(9H1D)2!``,;_0!"HPZ+^[O\`$,"`F=_`@IG?"?@@`P``
M```H@IG?"?@@`P$`!"0````````````````E`.`#`0`1!``````ER(`#`@`<
M/'01G"<MX)\#)?@``""`A-\``*7?"`"F9_#_`20DZ*$#*("'WS"`B-\E2$``
M)5"@`P""F=\)^"`#`````/__`!`````````````````"``,\+1AY`"`18V0X
M@&3<0(!BW#BPA&0'`$)D+Q!$``\`0BP%`$`4((-YW`,`(!,`````"``@`P``
M```(`.`#```````````"``,\+1AY`-@08V0X@&3<0(!EW#BPA&0O**0`^R@%
M`/X7!0`M*$4`>R@%``4`H!`X@7G<`P`@$P`````(`"`#``````@`X`,`````
M`````.#_O6<0`+S_`@`</"W@F0.($)QG"`"P_SB`D-\8`+__@+,"D@P`0!0P
M@X+?!`!`$$B`@M\P@YG?"?@@`P``1-Q0@)G?$!\Y9\?_$00``````0`")("S
M`J(8`+_?$`"\WP@`L-\(`.`#(`"]9P````#P_[UG``"\_P(`'#PMX)D#&!"<
M9SB`@M\(`+__^*]$9```@MP(`$`48(&9WU"`F=\(`+_?``"\WU@?.6?`_P`0
M$`"]9P````#X_R`3``````GX(`,`````]?\`$%"`F=\``````````$#]O6>P
M`KS_`@`</"W@F0.P#YQG\(*)W[@"O_^H`K/_H`*R_Y@"L?^0`K#_```BW0@`
MHV>(`J+_.`"(9'@`C60E4&``_P`,/```!]T```6-/C`'`#X2!P`X7@8`/CX'
M``#_0C`E$$<`H"@%?`/X9WTX,@8``BPE`"401P`D,,P``_BE?"401@`(``AE
M``!%_0@`0OWL_PT5$`!*90@"J&=H`&+<0`!GW!``9MP``&7<)A!'`"801@`F
M$$4`>"@"`/H7`@`E$*(``_A"?(``8OP(`&-D\O]H%():`CP``(O<$`"'W!@`
MB-P(`*S?F7E"9`@`AMP@`(K<^AX+`'@I"P`E**,`+6""`288Z`"Z:`8`+6"*
M`2089@"XQP8``_BE?"88:``M**P`)<`-`P/X&'\M**,`$`"NWP/XK'PF&/@`
M^GX,`"08:P`M<,(!>&D,`"UPR`$F&&<`)6BO`2T8;@`#^*U]NG`+`+A_"P`M
M&&T`)7CN`0/X<'P#^.]])V@,`!@`N=\D:+@!>'$0`/J.$``D**\`+<@B`R4H
MI0$E:-$!N'<,`+I@#``MR"<#)6#,`2``L=\#^(Y]+2BY``/XK7TG8!``+2BM
M`"08;@`MB"(")&"/`0/XN7PMP#@")6"#`?J6&0!X:1D`+6"8`;H8$`"XQQ``
M)6BR`248`P,#^'A\`_BM?22(N``M8(T!*`"EWP/XC7TG&!D`>($-`/J6#0`D
M&&X`+2BB`"THKP`E&'$`)7@2`BT890"XAQD``_CO?;HH&0`M&&\`)2@%`C``
MN=\#^'!\`_BO?"<H#0`DB(\!+<@B`_J6$``D*+@`>&$0`"UP+@,E*+$`)6"2
M`2THK@`#^(Q]N,\-`+IH#0`M**P`)<@M`S@`L=\#^*U\`_@Y?R=P$``D<,\!
M+8@B`GAA#0#ZE@T`)!AY`"W`.`(E&,,!)7"2`2T8>`"Z8!```_C.?;C'$``M
M&&X`)<`,`T``L=\#^&Q\`_@8?R=P#0`D<-D!+8@B`GB!#`#ZE@P`)"BX`"UX
M+P(E*,4!)7`2`BTHKP`#^,Y]N'\-`+IH#0`M**X`)7CM`4@`L=\#^*U\`_CO
M?2=P#``D<-@!+8@B`GB!#0#ZE@T`)!AO`"W(.0(E&,,!)7`2`BT8>0`#^,Y]
MN,\,`+I@#``M&&X`)<@L`U``L=\#^&Q\`_@Y?R=P#0`D<,\!+8@B`GB!#`#Z
ME@P`)"BY`"W`.`(E*,4!)7`2`BTHN``#^,Y]N,<-`+IH#0`M**X`)<`-`U@`
ML=\#^*U\`_@8?R=P#``D<-D!+8@B`GB!#0#ZE@T`)!AX`"UX+P(E&,,!)7`2
M`BT8;P`#^,Y]N'\,`+I@#``M&&X`)7CL`6``L=\#^&Q\`_CO?2=P#0`D<-@!
M+8@B`GB!#`#ZE@P`)"BO`"W(.0(E*,4!)7`2`BTHN0`#^,Y]N,\-`+IH#0`M
M**X`)<@M`V@`L=\#^*U\`_@Y?R=P#``D<,\!+8@B`GB!#0#ZE@T`)!AY`"W`
M.`(E&,,!)7`2`BT8>``#^,Y]N,<,`+I@#``M&&X`)<`,`W``L=\#^&Q\`_@8
M?R=P#0`D<-D!+8@B`GB!#`#ZE@P`)"BX`"UX+P(E*,4!)7`2`BTHKP`#^,Y]
MN'\-`+IH#0`M**X`)6CM`7@`L-\#^+%\`_BO?2=H#``D:+@!+8`"`GAQ$0#Z
MEA$`)!AO`"W(&0(E&*,!)6C2`2T8>0`#^*U]N,\,`+I@#``M&&T`)6`L`X``
MK=\#^'!\`_B9?2=P$0`D*+D`+6BB`?J6$``D<,\!>&$0`"W`N`$E<,4!)6"2
M`2UPV`$#^(Q]N,<1`+HH$0`M<,P!)2@%`X@`L=\#^,Q]`_BX?"=H$``D&'@`
M+8@B`OJ6#``D:+D!>"D,`"UX+P(E:*,!)2BR`+H8$``M:*\!`_BE?+A_$``M
M:*4!)7CC`9``L-\#^*-]`_CO?2<H#``DB,\!+8`"`OJ6`P`D*+@`>'$#`"W(
M&0(E*+$`)7#2`2THN0`#^,Y]N,\,`+I@#``M**X`)6`L`Y@`L=\#^+E\`_B.
M?2=@`P`D:*X!+8@B`OJ6&0`D8(\!>($9`"W`.`(E8(T!)8`2`KAO`P"Z&`,`
M+6"8`248HP&@`++?`_@0?BV`D`$#^&U\)V`9`"1@C@$D**T`+9!"`@/X&'XE
M$(4!+7A/`GB)&``M$$\`NB@9`/J>&`"X?QD`)7CE`25@,P(F&&\``_B,?2U@
M3``F&'``V6X"/*@`L-^AZT(T`_B9?2V``@+ZCAD`+7`.`G@I&0`#^&-\)2BQ
M`"T8;@"X=Q@`NL`8`"5PV`$#^*5\+1AE`"8H[@$F**P`L`"LWP/X<'PM8((!
M^HX0`'C!$``M:(T!)<`1`P/XI7PM**T`N&<9``/X&'^ZR!D`)6"9`2W`N`"X
M`*7?`_@9?R:(S`$M**(`)H@C`OJ6&0`#^.]]>&D9`"T8KP`E:+(!`_@E?BT8
M90"X?Q```_BM?;J`$``E>/`!+6AM`,``H]\#^+!])BB/`2;`N`#ZCA``+1AB
M``/XSGUX*1``+1AN`"4HL0`#^`Y_+1AN``/XI7RX=QD`NL@9`"5PV0$M*&4`
MR`"CWP/XN'PFR.X!`_B1?2T88@`F:"T#>&$8`/K.&``M&'$``_BM?25@F0$M
M&&T``_B,?;AO$`"Z@!``)6BP`2U@;`#0`*/?`_B9?2:`S0$#^/%]+1AB`"9X
M!0+ZAAD`>"D9`"T8<0`#^.]])2BP`"T8;P`#^*5\N'\8`+K`&``E>/@!+2AE
M`-@`H]\#^+A\)H"O`0/XT7TM&&(`)G`,`OJ&&`!X81@`+1AQ``/XSGTE8)`!
M+1AN``/XC'VX=QD`NL@9`"5PV0$M8&P`X`"CWP/XF7TF@.X!`_BQ?2T88@`F
M:`4"^H89`'@I&0`M&'$``_BM?24HL``M&&T``_BE?+AO&`"ZP!@`)6BX`2TH
M90#H`*/?`_BX?":`S0$#^/%]+1AB`"9X#`+ZAA@`>&$8`"T8<0`#^.]])6"0
M`2T8;P`#^(Q]N'\9`+K(&0`E>/D!+6!L`/``H]\#^)E])H"O`0/XT7TM&&(`
M)G`%`OJ&&0!X*1D`+1AQ``/XSGTE*+``+1AN``/XI7RX=Q@`NL`8`"5PV`$M
M*&4`^`"CWP/XN'PF@.X!`_BQ?2T88@`F:`P"^H88`'AA&``M&'$``_BM?25@
MD`$M&&T``_B,?;AO&0"ZR!D`)6BY`2U@;````:/?`_B9?2:`S0$#^/%]+1AB
M`"9X!0+ZAAD`>"D9`"T8<0`#^.]])2BP`"T8;P`#^*5\N'\8`+K`&``E>/@!
M+2AE``@!H]\#^+A\)H"O`0/XT7TM&&(`)G`,`OJ&&`!X81@`+1AQ``/XSGTE
M8)`!+1AN``/XC'VX=QD`NL@9`"5PV0$M8&P`$`&CWP/XF7TF@.X!`_BQ?2T8
M8@`F:`4"^H89`'@I&0`M&'$``_BM?24HL``M&&T``_BE?+AO&`"ZP!@`)6BX
M`2TH90`8`:/?`_BX?":`S0$#^/%]+1AB`"9X#`+ZAA@`>&$8`"T8<0`#^.]]
M)6"0`2T8;P`#^(Q]N'\9`+K(&0`E>/D!+6!L`"`!H]\#^)E])H"O`0/XT7TM
M&&(`)G`%`OJ&&0!X*1D`+1AQ``/XSGTE*+``+1AN``/XI7RX=Q@`NL`8`"5P
MV`$M*&4`*`&CWP/XN'PF@.X!`_BQ?2T88@`F:`P"^H88`'AA&``M&'$``_BM
M?25@D`$M&&T``_B,?;AO&0"ZR!D`)6BY`2U@;``P`:/?`_B9?2:`S0$#^/%]
M+1AB`"9X!0+ZAAD`>"D9`"T8<0`#^.]])2BP`"T8;P`#^*5\N'\8`+K`&``E
M>/@!+2AE`#@!H]\#^+A\)H"O`0/XT7TM&&(`)F`,`GAQ&`#ZAA@`+1AQ``/X
MC'TE<-`!+1AL``/XSGVX9QD`NL@9`"5@F0$MR&X`0`&CWP/X,'\F<.P!+1!B
M``/XK7TF*,4!>!D0`/IV$``M$$T``_BE?"48;@"X;Q@`NL`8`"5HN`$M$$4`
M`_AC?"UP0P`E*(T!QB,"/"0HN0`W[T(T2`&YW[@0`@`#^-A])!B-`?J.&``E
M**,`+<@B`P/X[WUX&1@`+<@O`R48<0"X?Q```_BE?+J`$``E>/`!+2BY``/X
M8WPM**,`4`&PWR48KP$#^+E\)!AN`"1PKP'ZCAD`)1AN`"V``@)X<1D``_B,
M?2V`#`(#^&-\)6#1`;AW&`"ZP!@`)7#8`2T8<``#^(Q]+1AL`%@!L-\E8.X!
M`_AX?"0HA0$D8.X!^HX8`"4HK``M@`("`_BM?7AA&``M@`T")6"1`;AO&0`#
M^*5\NL@9`"5HN0$M*+```_B,?2THK`!@`;#?)6#-`0/XN7PD&(,!)&#-`?J.
M&0`E&&P`+8`"`@/X[WUX81D`+8`/`B5@D0&X?Q@``_AC?+K`&``E>/@!+1AP
M``/XC'TM&&P`:`&PWR5@KP$#^'A\)"B%`21@KP'ZCA@`)2BL`"V``@(#^,Y]
M>&$8`"V`#@(E8)$!N'<9``/XI7RZR!D`)7#9`2THL``#^(Q]+2BL`'`!L-\E
M8.X!`_BY?"08@P$D8.X!^HX9`"48;``M@`("`_BM?7AA&0`M@`T")6"1`;AO
M&``#^&-\NL`8`"5HN`$M&'```_B,?2T8;`!X`;#?)6#-`0/X>'PD*(4!)&#-
M`?J.&``E**P`+8`"`@/X[WUX81@`+8`/`B5@D0&X?QD``_BE?+K(&0`E>/D!
M+2BP``/XC'TM**P`@`&PWR5@KP$#^+E\)!B#`21@KP'ZCAD`)1AL`"V``@(#
M^,Y]>&$9`"V`#@(E8)$!N'<8``/X8WRZP!@`)7#8`2T8<``#^(Q]+1AL`(@!
ML-\E8.X!`_AX?"0HA0$D8.X!^HX8`"4HK``M@`("`_BM?7AA&``M@`T")6"1
M`;AO&0`#^*5\NL@9`"5HN0$M*+```_B,?2THK`"0`;#?)6#-`0/XN7PD&(,!
M)&#-`?J.&0`E&&P`+8`"`@/X[WUX81D`+8`/`B5@D0&X?Q@``_AC?+K`&``E
M>/@!+1AP``/XC'TM&&P`F`&PWR5@KP$#^'A\)"B%`21@KP'ZCA@`)2BL`"V`
M`@(#^,Y]>&$8`"V`#@(E8)$!N'<9``/XI7RZR!D`)7#9`2THL``#^(Q]+2BL
M`*`!L-\E8.X!`_BY?"08@P$D8.X!^HX9`"48;``M@`("`_BM?7AA&0`M@`T"
M)6"1`;AO&``#^&-\NL`8`"5HN`$M&'```_B,?2T8;`"H`;#?)6#-`0/X>'PD
M*(4!)&#-`?J.&``E**P`+8`"`@/X[WUX81@`+8`/`B5@D0&X?QD``_BE?+K(
M&0`E>/D!+2BP``/XC'TM**P`L`&PWR5@KP$#^+E\)!B#`21@KP'ZCAD`)1AL
M`"V``@(#^,Y]>&$9`"V`#@(E8)$!N'<8``/X8WRZP!@`)7#8`2T8<``#^(Q]
M+1AL`+@!L-\E8.X!`_AX?"0HA0$D8.X!^HX8`"4HK``M@`("`_BM?7AA&``M
M@`T")6"1`;AO&0`#^*5\NL@9`"5HN0$M*+```_B,?2THK`#``;#?)6#-`0/X
MN7PD&(,!)&#-`?J.&0`E&&P`+8`"`@/X[WUX81D`+8`/`B5@D0&X?Q@``_AC
M?+K`&``E>/@!+1AP``/XC'TM&&P`R`&PWR5@KP$#^'A\)"B%`21@KP'ZCA@`
M)2BL`"V``@(#^,Y]>&$8`"V`#@(E8)$!N'<9``/XI7RZR!D`)7#9`2THL``#
M^(Q]+2BL`-`!L-\E8.X!`_BY?"08@P$D8.X!^HX9`"48;``M@`("`_BM?7AA
M&0`M@`T")6"1`;AO&``#^&-\NL`8`"5HN`$M&'```_B,?2T8;`#8`;#?)6#-
M`0/X>'PD8(4!)"C-`?J.&``E8(4!+8`"`@/X[WUX*1@`+8`/`B4HL0"X?QD`
M`_B,?;K(&0`E>/D!+6"0`0/XI7PM8(4!)2BO`208HP`D**\!)1AE`.`!I=\#
M^)E]+2BB`/J&&0!X$1D``_C.?2UPK@`E$%```_AC?"T8;@`#^$)\+1AB`+AW
M&``Q90(\NL`8`"5PV`'K8$)DZ`&EWW@0`@`#^'A\)H#N`2THH@`#^*U])F`,
M`GB1&`#ZAA@`+2BM``/XC'TED%`"+2BL`+AO&0`#^%)^NL@9`"5HN0$MD+(`
M\`&EWP/X47XF8,T!+2BB`"9@@P'ZAA$``_CO?7C)$0`M&*\`)<@P`P/XA7TM
M&&4`N&<8``/X.7^ZP!@`)6"8`2W(>0#X`:/?`_@P?R8HK`'Z?A``+1AB``/X
MSGUXP1``)BBR`"T8;@`#^*5\)<`/`RT890"X?Q$``_@8?[J($0`E>/$!+<!X
M```"H]\#^!%_)BB/`2;(N0#Z=A$`+1AB``/XK7UX*1$`+1AM`"4HK@`#^"U_
M+1AM`+AW$``#^*5\NH`0`"5PT`$M*&4`"`*CWP/XL'PF:.X!`_B9?2T88@`F
M:+@!>&$0`/K&$``M&'D``_BM?25@F`$M&&T``_B,?;AO$0"ZB!$`)6BQ`2U@
M;``0`J/?`_B9?2;`S0$#^/%]+1AB`"9X!0/ZQAD`>"D9`"T8<0`#^.]])2BX
M`"T8;P`#^*5\N'\0`+J`$``E>/`!+2AE`!@"H]\#^+A\)H"O`0/XT7TM&&(`
M)G`,`OJ&&`!X81@`+1AQ``/XSGTE8)`!+1AN``/XC'VX=QD`NL@9`"5PV0$M
M8&P`(`*CWP/XF7TF@.X!`_BQ?2T88@`F:`4"^H89`'@I&0`M&'$``_BM?24H
ML``M&&T``_BE?+AO&`"ZP!@`)6BX`2TH90`H`J/?`_BX?":`S0$#^/%]+1AB
M`"9X#`+ZAA@`>&$8`"T8<0`#^.]])6"0`2T8;P`#^(Q]N'\9`+K(&0`E>/D!
M+6!L`#`"H]\#^)E])H"O`0/XT7TM&&(`)G`%`OJ&&0!X*1D`+1AQ``/XSGTE
M*+``+1AN``/XI7RX=Q@`NL`8`"5PV`$M*&4`.`*CWP/XN'PF@.X!`_BQ?2T8
M8@`F:`P"^H88`'AA&``M&'$``_BM?25@D`$M&&T``_B,?;AO&0"ZR!D`)6BY
M`2U@;`!``J/?`_B9?2:`S0$#^/%]+1AB`"9X!0+ZAAD`>"D9`"T8<0`#^.]]
M)2BP`"T8;P`#^*5\N'\8`+K`&``E>/@!+2AE`$@"H]\#^+A\)H"O`0/XT7TM
M&&(`)G`,`OJ&&`!X81@`+1AQ``/XSGTE8)`!+1AN``/XC'VX=QD`NL@9`"5P
MV0$M8&P`4`*CWP/XF7TF@.X!`_BQ?2T88@`F:`4"^H89`'@I&0`M&'$``_BM
M?24HL``M&&T``_BE?+AO&`"ZP!@`)6BX`2TH90!8`J/?`_BX?":`S0$#^/%]
M+1AB`"9X#`+ZAA@`>&$8`"T8<0`#^.]])6"0`2T8;P`#^(Q]N'\9`+K(&0`E
M>/D!+6!L`&`"H]\#^)!])LBO`0/XT7TM&&(`)G`E`_K.$`!X*1``+1AQ``/X
MSGTE*+D`+1AN`+C/&``#^*5\NL`8`"7(.`,M*&4`:`*CWP/XN'PF</D!`_BQ
M?2T88@`F8,P!>&D8`/IV&``M&'$``_B,?25HK@$M&&P`N'<0``/XK7VZ@!``
M)7#0`2UH;0!P`J/?`_BP?29@+@/ZCA``+1AB``/X[WTF8(4!>"D0`"T8;P`#
M^(Q])2BQ`"T8;``#^*5\N&<8`+K`&``E8)@!+<!E`'@"I=\#^`]_)AC,`2TH
MH@`#^#E_)FAM`/J.#P!X&0\`+2BY``/XK7TE&'$`+2BM``/X8WRX;Q``NH`0
M`"5HL`$M**,`@`*CWP/XI7PFR(T!+1!B``/XSGTFP#@#>!D%`/K.!0`M$$X`
M)1AY``/X#G\#^&-\+1!.`"T00P`#^$)\N!\/`"T02P"Z>`\``_A"?"48;P``
M`(+\`_AC?`/XJWT#^()]+3#%`"T89P`M*&@!+1!*`(@"J-\``"?=`_C&?`/X
M8WP#^*5\`_A"?`@`AOP0`(/\&`"%_`D`!Q4@`(+\N`*_W[`"O-^H`K/?H`*R
MWY@"L=^0`K#?"`#@`\`"O6?`@IG?"?@@`P````"P_[UG0`"\_P(`'#PMX)D#
M2`"__S@`MO\P`+7_*`"T_R``L_\8`++_$`"Q_P@`L/]'`(`0`/B<9RB!@M\`
M`%/<0P!@$@```````(*`/@!`$#T``R0\`$,0)1"``#T`!B0!`$)D``!#@`,`
M8!`OD$0`_/]F%`$`0F0`D!(```!PWA(``!(EH*``):B``"6(8`(]`!8D,(&9
MWR4@``(E,$`""?@@`R4HH`($`$`4+1@2`@``8H`2`%80``````@`,68``##>
M]/\`%C"!F=](`+_?)1```D``O-\X`+;?,`"UWR@`M-\@`+/?&`"RWQ``L=\(
M`+#?"`#@`U``O6<`````+X@S`ON($0```)&N2`"_WP$`4F8M@!(")1```D``
MO-\X`+;?,`"UWR@`M-\@`+/?&`"RWQ``L=\(`+#?"`#@`U``O6<`````S/\`
M$"60``#>_P`0)8```+#_O6=``+S_`@`</"W@F0.H]IQG,`"S__""D]\X`+3_
M*`"R_R``L?\8`+#_2`"__P``8MY0@)#?*(&2WR6(@``(`*+_!`"T9S`X$&8E
M*(`")<@``I3_$00E("`"$@!`$`0`HH\`````^!@"````0MXM$$,`"`!#W/3_
M8!```$/\"`!"9`@`0]S]_V`4``!#_"4H@`(ER``"@_\1!"4@(`+Q_T`4!`"B
MCP@`H]\``&+>"0!B%$@`O]]``+S?.`"TWS``L]\H`++?(`"QWQ@`L-\(`.`#
M4`"]9\""F=\)^"`#``````````"@_[UG6`"__U``O/\H`+/_(`"R_Q@`L?\0
M`+#_2`"W_T``MO\X`+7_,`"T_P(`'#P``**`+>"9`\#UG&<!`*-D)8"@`#T`
M0CCP@I+?"H!B``B"F=\``$+>)8B``"4@``((`*+_"?@@`P````!0@)G?!`"E
M9R4@(`(P.#EG4/\1!"680`!8`$`0"(*9WR4@0``)^"`#):!``"L04P!&`$`0
M!`"UCRB!E-_XJ!4````B@GP`0!`]``,D>@!#$#T`!"0#```0)1`@`@4`9!``
M`````0!"9```0X#[_V`4`````"\040``$`(`2(*9WP(`9&8M(((`"?@@`P``
MD]XMF'4";0!`$```8OX$`*./``""WO@8`P`M$$,```!#W```(H(!`"1F"@!`
M$```8J`&```0/0`%)`````#__X*``0!C9`,`0!```&*@^_]%%`$`A&0]``0D
M`0!B9```9*```````0`09O__`X(!`$)D_/]@%/__0Z`E$```"`"DWP``0]Y/
M`(,46`"_WU``O-](`+??0`"VWS@`M=\P`+3?*`"SWR``LM\8`+'?$`"PWP@`
MX`-@`+UG``````$`$&;__P*"`0"49NO_0!#__X*B`0`09O__`H(!`)1F]_]`
M%/__@J+E_P`0)1```"B!E-\``)?>``#BWBT`0!`E$.`"`P``$"4@````````
M)2!@``@`0F0``$7<`0"#)/O_H!0EL&```P"$)/@@!``X@(+?D,-#C`\`8!!(
M@IG?4(*9WR4H@``)^"`#)2#@`AL`0!```(+^^*@6`"480``!`,)F^!`"`"T8
M8@```&#\D/\`$`0`MJ\!``,D"?@@`Y##0ZP.`$`0"(.9W_BH%@`E,*`")2C@
M`@GX(`,E($``)1A``.[_`!```(+^D/\`$"40```0``0DW?\`$"6P``"O_P`0
M__\"),""F=\)^"`#``````````#0_KUG(`&\_P(`'#PMX)D#\/*<9_@`L__P
M@I/?*`&__Q@!M_\0`;;_"`&U_P`!M/_P`++_Z`"Q_^``L/\``&+>V`"B_P0`
M@!````````""@!$`0!0EB(``V`"CWP``8MYJ`&(4*`&_WR`!O-\8`;??$`&V
MWP@!M=\``;3?^`"SW_``LM_H`+'?X`"PWP@`X`,P`;UG`````/B`F=\)^"`#
M`````.S_0!`ED$``4("4WU"`E=]89I1F);"@`T`]M69(@9G?``````GX(`,E
M($`"$P!`$`"!F=\3`$.0+@`$)",8@P`6`&`4`````!0`0Y#U_V`02(&9WR,@
M@P`\`(`0`````",@!``/`(`42(&9WPGX(`,E($`"[_]`%`"!F=\)^"`#)2!`
M`MB"F=\)^"`#)2`@`LC_`!```````````.'_8!!(@9G?"(*9WR4@(`()^"`#
M$P!09`B"F=\E(``""?@@`R6X0`!(@IG?+1#B`@`@`@`)^"`#`@"$)/"`F=\E
M($``)4@``B5`(`(E.(`"__\&)`$`!20)^"`#);A``""!F=\E,,`")2C@`@GX
M(`,#``0D__\#)`4`0Q`@`**/`$`#)`#P0C`+`$,0`````*B"F=\)^"`#)2#@
M`@"#F=\)^"`#)2#@`K?_`!!(@9G?Q?\`$!4`1)`ER*`"@/\1!"4@X`+V_P`0
M`(.9W\""F=\)^"`#`````.#_O6<0`+S_`@`</"W@F0/8\)QG``"P_[""D-\8
M`+__"`"Q_QB!F=\EB(``"?@@`P``!(X0@9G?^`%&9"4H(`()^"`#`P`$)`D`
M0!`8@9G?&`"_WQ``O-\(`+'?``"PWR40```(`.`#(`"]9P`````)^"`#```$
MC@!``R08`D*,`/!",`@`0Q`8@9G?"?@@`P``!(X`H`,T&`)"C`#P0C#L_T,4
M&`"_WX"!F=\E("`""?@@`P(`!208`+_?$`"\WP@`L=\``+#?`0!"+`@`X`,@
M`+UG`````+#OO6=`$+S_`@`</"W@F0,`\)QG,!"S_R@0LO\EF(``\(*2WU"`
MA-\X$+3_(!"Q_T@0O_\8$+#_D(*9WP@`L6<``$+>):"@`/\/!B0E*"`"8&:$
M9`@0HO\)^"`#```````0`@`D`$`8$!"C9___4"0M&'``^.]C@!T`8!"P@9G?
M)8!``"4P``(O``4D"?@@`R4@(`(8`$`0L(*"WQB!F=\)^"`#``!$C%B!F=\E
M.``")3`@`B4H8`()^"`#)2!```@0H]\``$+>%@!B%$@0O]]`$+S?.!"TWS`0
ML]\H$++?(!"QWQ@0L-\(`.`#4!"]9^3_`!8`````L(*"WQB!F=\)^"`#``!$
MC(B"F=\E,(`")2A@`@GX(`,E($``Z/\`$`````#`@IG?"?@@`P````#P_[UG
M``"\_P(`'#PMX)D#T.Z<9[""@M\(`+__&(&9WPGX(`,``$2,6("'WU"`A=_@
M@H;?X(&9WZBGYV1P9J5D"?@@`R4@0``(`+_?``"\WP@`X`,0`+UGX/^]9Q``
MO/\"`!P\+>"9`WCNG&<(`+#_L(*0WQ@`O_\8@9G?"?@@`P``!(Y@@)G?W?\1
M!"4@0``8@9G?"?@@`P``!(Y0@(C?4("%WV!J"&6(@9G?:("&WR5(```E.``!
MD&:E9`GX(`,E($``&`"_WQ``O-\(`+#?"`#@`R``O6>@W[UG4""\_P(`'#PM
MX)D#^.V<9T`@L?_P@I'?6""__S@@L/]@@IG?2""R_P``(MX8`+!G*""B_PGX
M(`,`````4(")WU"`A]_P@)G?J&8I925`0`"P9N=D`1`&)`$`!20)^"`#)2``
M`B$`0`20@IG?(!"R9R4@``(`$`8D"?@@`R4H0`(,`**O#`"PCQ@```9(@IG?
M"?@@`P$`!"8)`$`0)1A``/B"F=\,`*:/)2A``@GX(`,E($``+8!0`"480```
M``"B*""EWP``)-X*`*04)1!@`%@@O]]0(+S?2""RWT`@L=\X(+#?"`#@`V`@
MO6?T_P`0)1@``,""F=\)^"`#```````````"``,\+1AY`/#L8V1P@'G<N?\`
M$`````"`[[UG:!"\_P(`'#PMX)D#V.R<9W`0OO\H$+#_\(*>WR6`@`!0@)G?
M4("$WW@0O_\X$++_,!"Q_V`0M_]8$+;_4!"U_T@0M/]`$+/_``#"W\AFA&0P
M.#EG)8B@`!0`I6<8$*+_'/T1!``````8@IG?+P`%)"4@``()^"`#)9!``!@`
M0!`(@IG?4("$WU"`F=\E*``"<#HY9Y_]$0389H1D)1```A@0I-\``,/?>P"#
M%'@0O]]P$+[?:!"\WV`0M]]8$+;?4!"UWT@0M-]`$+/?.!"RWS`0L=\H$+#?
M"`#@`X`0O6<E(``""?@@`U"`E-]X@9G?Z&:%9B4@(`()^"`#`*@"`.#_0!`E
MF$``4(""WU"`E]\(`*+_4("6WP``8H+P9O=F00!`$/AFUF8`````!@!`$CB#
MF=\E*&`""?@@`R4@0`(Q`$`0>(&9WPB"F=\)^"`#)2!@`B\``R0`$`(`+2!B
M`O__A(`&`(,4+P`%)/__0B0M&&("__]D@/S_A1```&"@`0"C)B$08@``$$(H
MO?]`$/"`F=\8`+%G)4!@`B50``(E2.`")3C``@`0!B0!``4D)2`@`@GX(`.P
M@I/?&(&9WPGX(`,``&2.((&9W_@!1F0E*"`""?@@`P,`!"0*`$`4>(&9WQB!
MF=\)^"`#``!DC@"``S08`D*,`/!",!8`0Q"`@9G?>(&9W^AFA68)^"`#)2``
M`)O_0!`EF$````!B@L+_0!0`````!P!`$CB#F=\(`*+?P&9%9`GX(`,E($`"
M\?]`$'B!F=\(`*+?P&939,O_`!`!``(D`0`%)`GX(`,E("`"Z/]`%'B!F=]0
M@(3?4("9WR4H(`)P.CEG)?T1!-AFA&3(@9G?"?@@`R4@(`*#_P`0`````,""
MF=\)^"`#````````A8`'`*`0)1"```$`@V0O`*0X``!E@`H09`#\_Z`4`0!C
M9`@`X`,``````````.#_O6<0`+S_`@`</"W@F0,8`+__"`"Q_P``L/\@`(`0
M`.J<9P``D8`=`"`2)8"```B"F=\)^"`#`````/__0F0M$`("*Q@"`C(`8!`O
M``,D``!$@"8`@Q0`````!0``$"\`!"0```````!#@"``9!0`````__]"9/O_
M`A8`````+P`")`8`(A)0@(3?R(&9WPGX(`/P9H1D"```$!@`O]](@IG?"?@@
M`P(`!"0(`$`0+@`#)```0Z08`+_?$`"\WP@`L=\``+#?"`#@`R``O6<8`+_?
M$`"\WP@`L=\``+#?)1````@`X`,@`+UG``````0``!`O``0D``!#@`<`9!``
M````__]"9"L8`@+Z_V`4`````-K_`A(`````!0``$"\`!"0```````!#@`4`
M9!0`````__]"9"L8`@+Z_V`4+S!0``(`PF0!$$(LX/]`$#B`D=^8@9G?)2@`
M`I"S)&8`$`<D"?@@`P$`QF08`+_?D+,B9A``O-\(`+'?``"PWP@`X`,@`+UG
M</^]9X``O/\"`!P\+>"9`WCHG&=``+#_6("#WU"`D-]8`+/_4("$W_""D]^(
M`+__B#D09H"G8F1X`+?_<`"V_V@`M?]@`+3_4`"R_T@`L?^`IV?<"`!&W!``
M1=P8`$/<``!HWB``0I0`9X1D)<@``C@`J/\0`*?_&`"F_R``I?\H`*/_4OP1
M!#``HJ=0@(3?)<@``A!GA&1-_!$$4("4WU"`A-\ER``"&&>$9$C\$010@)7?
M4("$WR7(``(H9X1D0_P1!%"`EM\P9X1F)<@``C_\$010@)??4("$WR7(``)`
M9X1D.OP1!%"`D=_(9J1F)<@``C;\$00,`+)G4&?$9B7(``(R_!$$,#@Q9B7(
M``(O_!$$8&?D9E"`A-\ER``"*_P1!'!GA&10@(3?)<@``B?\$0389H1D4("$
MWR7(``(C_!$$@&>$9%"`A-\ER``"'_P1!)!GA&10@(3?)2A``B7((`+$^Q$$
MH&>$9#``0!`E*$``4("0WW`Z$&8ER``"3?P1!&!GY&90@(3?)2A``B7((`*X
M^Q$$N&>$9`4`0!!0@(3?)2A``"7(``)"_!$$T&>$9%"`A-\E*$`")<@@`JW[
M$03@9X1D'0!`$"4H0``ER``"./P1!,AFI&90@(7?,&>$9B7(``(S_!$$&&BE
M9#@`H]\``&+>*@!B%(@`O]^``+S?>`"WWW``MM]H`+7?8`"TWU@`L]]0`++?
M2`"QWT``L-\(`.`#D`"]9P````!0@)#?U/\`$'`Z$&8`````4("$WR4H0`(E
MR"`"BOL1!/!GA&0&`$`0)2A``"7(``(5_!$$4&?$9MW_`!!0@(7?4("%WS"!
MF=\*``8D"&BE9`GX(`,A`*1GU/]`%"L`I6<ER``""/P1!%!GQ&;0_P`04("%
MW\""F=\)^"`#`````-#_O6<@`+S_`@`</"W@F0/(Y9QG&`"Q_Q``L/\X@)'?
M\(*0WR@`O_\```3>$+`BCO__`R0(`*3_"P!#$%"`A-\(`*3?```#WA@`@Q0H
M`+_?(`"\WQ@`L=\0`+#?"`#@`S``O6<`````4("9WP0`I6<P.#EG5/L1!%!G
MA&0(`$`0````````0H`%`$`0`````#``0C@K$`(`Z?\`$!"P(JXE$```YO\`
M$!"P(J[`@IG?"?@@`P````#P_[UG``"\_P(`'#PMX)D#$.6<9[B"F=\(`+__
M"?@@`P`````8@YG?"?@@`R4@0``'`$`0````````0MP(`+_?``"\WP@`X`,0
M`+UG`````/K_`!`E$```,/^]9[@`O/\"`!P\+>"9`[CDG&>P`+?_\(*7W\``
MOO^H`+;_H`"U_Y@`M/^0`+/_B`"R_X``L?]X`+#_R`"__P``XMY0@)'?:`"B
M_U"`@M]0@)#?.&A"9$``HO]0@(+?4("6WT!H0F1(`*+_4(""WU"`@]](:$)D
M4`"B_U"`@M]0@)/?8&A"9%"`E=\H:#%F(&@09E@`HO_H9L)F$`"C_R6@@``P
M`+'_.`"P_V``H/\P`+)G+`"^9S`X<V9P.K5F"@``$`@`HO\E*(`""?@@`R4@
MP`(F`$`0"(*9WQ,``!((`%)F)8@``@@`4-XE*,`#)<A@`O#Z$00E("`"!`!`
M$"6P0````$*`[_]`%$"#F=\E*(`")2`@`B7(H`)V^Q$$"`!29O#_`!8EB``"
M:`"CWP``XMXK`&(4R`"_W\``OM^X`+S?L`"WWZ@`MM^@`+7?F`"TWY``L]^(
M`++?@`"QWW@`L-\(`.`#T`"]9P`````)^"`#)2"``@B"F=\E(,`""?@@`Q@`
MHO\8`*7?2(*9WRT0H@`)^"`#`@!$9`@`J=\E($``&`"B_Q``HM_P@)G?)5#`
M`B5`@`+X9D=D__\&)`GX(`,!``4D&`"KWR4@(`(ER*`"2/L1!"4H8`&__P`0
M`````,""F=\)^"`#`````!"`O6?8?[S_`@`</"W@F0/(XIQGP'^U_[A_M/^P
M?[/_J'^R_^A_O__@?[[_T'^W_\A_MO^@?['_F'^P_U"`A=\`_KUG0`"G9___
M`CPEJ(``4($$-"4PH``M((<`,`"E_\Q^163P@H/?+2B%`,AFQ&10@08T+3#'
M`"T0P@`@`*/_2($&-```8]PM,,<```##_%"`@]]0@)3?@&AC9-!^0_Q0@(/?
M,#B49L!F8V38?D/\4("#WU"`DM^(:&-D"']#_%"`@]]0@)/?D&AC9!!_0_Q0
M@(/?)<B``IAH8V08?T/\4("#W]!G4F:@:&-D(']#_%"`@]]P:'-FJ&AC9.!^
M0/P`?U+\*']`_.A^4_SP?D/\;?H1!/A^0/P$`$`0>("9WP``0X!8`6`4)2!`
M`"+_$00`````70%`$"6`0``(@IG?"?@@`R4@``)(@IG?>!`"``GX(`,!`$1D
M```#@@\`8!`EB$``4("'WR68(`*X:/9D```(DO"`F=\E(&`")3C``O__!B0!
M``4D"?@@`P$`$&8```*"]O]`%`(`<V;__Q8\0`"C9U"!`C0`?]!F+1!#`"V`
M4`!0@)/?4($"-,Q^UF8M$$,`)2!``BVP5@`'```06#]S9@`````(`!!F````
M````!-X4`(`04($"-"7(@`(U^A$$)2C``O?_0!`ED$````!"@/3_0!`ER&`"
M^/L1!"4@0`+R_T`0"``09OC_$&;(@9G?"?@@`R4@0`(A`$`4);A``%"!`C1`
M`*-G__\2/"T00P!0@)/?+9!2`-!^4-XEL```"```$%@_<V8``````0#6)O@0
M%@`M$$("T'Y0W!```!(EN``````"@@P`0!`ER&`"VOL1!"4@``+T_T`0R(&9
MWPGX(`,E(``"\/]`$"6X0``$```0"(*9WP`````EN```"(*9WR4@X`()^"`#
M4("3WPB"F=\E("`""?@@`R6`0`!(@IG?+8`"`@"`$``$!!`F"?@@`R4@``)0
M@(K?4("'W_"`F=\E($``)5@@`L!H2F7P9FEF)4#@`LAHYV3__P8D`0`%)`GX
M(`,ED$``T(&9W\`!!20)^"`#)2!``O__`R0L`$,0N(&9W[""EM\8@9G?"?@@
M`P``Q(X0@9G?^`%&9"4H0`()^"`#`P`$)#,`0!`EB$``$(."WU"`AM]`@9G?
M``"GW@``1-PE0$`"8&G&9`$`!20)^"`#)8```$``HV=(@0(T+1!#````1-P@
M`*+?``!#W)@"@Q0E$``"``*]9^A_O]_@?[[?V'^\W]!_M]_(?[;?P'^UW[A_
MM-^P?[/?J'^RWZ!_L=^8?[#?"`#@`_!_O6<)^"`#`````!$``R0``$F,T/\C
M$1"#@M]0@(;?0(&9WP``I]X``$3<)4!``MAHQF0!``4D"?@@`R6```#;_P`0
M0`"C9P`````8@9G?"?@@`P``Q(X`0`,D&`)"C`#P0C#(_T,4$(."WQB!F=\)
M^"`#``#$CKB"F=\)^"`#*`)7C,#_5Q00@X+?&(&9WPGX(`,``,2.P`$#)!@"
M0HS_`4(PN/]#%!"#@M](@IG?"?@@`R4@``)``*1G4($#-"T89`#__P4\4("$
MW\Q^I60M*&4`0&B$9"7(@`*!^1$$)8!``)\`0!#(@9G?)2!```GX(`,``+3>
M@("9WR4H0`!"_!$$)2"``I8`0!`EL$``"(*9WPGX(`,E(,`"`*`"``0`@BH3
M`$`4B("9WU"`A=\X@YG?_/^$9AAII60)^"`#+2#$`@L`0!2(@)G?!``").<!
M@A+\_X(F+1#"`O__0X`O``(DX@%B$`````"(@)G?`````.G]$00`````"`!`
M%%"`GM_X@9G?)2@```GX(`,E(,`"=0!`%"@`HO]0@)[?4("%WU"`A-]P.MYG
M&&BE9%!GA&0ER,`#VOD1!%"`E-]@@IG?8&J79@GX(`-0@)3?4("'W_"`F=\E
M6.`")5!``/!F:68E0$`".&GG9/__!B0!``4D)2```@GX(`/__Q4D$0`6)!,`
M`!!(:91F"?@@`P```````$*,%`!6%&""F=\)^"`#`0`Q)O"`F=\E6"`")5!`
M`/!F:68E0$`")3B``O__!B0!``4D)2```@GX(`,``+?_T(&9W\`!!20)^"`#
M)2```NG_51"X@9G?`(.9WPGX(`,E($`",`"BWR4H``(ER,`#I_D1!,AF1&20
M@)G?YOT1!"4@``)%_P`00`"C9P````"0@)G?X/T1!!@`HO\8`*+?R(&9WPGX
M(`,E($``.O\`$"6`0`#__Q$\0`"E9U"!`S3,?B)F+1AE`"4@8`(MF&(`4($"
M-"T010`!`!8D+8A1`"7(@`+Z^!$$)2A@`@0`0!`E&,`"``!#@`T`8!0E&,`"
M^!@#`"T8(P+H?F3<]/^`%`$`UB9(@IG?#0`$)`GX(`-0@)#?>&@09I#^`!`E
MB$``R(&9WPGX(`,E($``\/]`$"48P`)__@`0)8!```````!J_P`0``"VWFB"
MF=\E($```@`&).[_!20EJ$``"?@@`___$3Q``*-G4($"-"T00P#X?S1F+:!4
M`"B#F=\&``8D)2B``@GX(`,E(*`"0`"C9U"!`C0M$$,`+1!1`/A_0Y`$`&`4
M0P`$)/E_0Y!N`60000`$)&B"F=\H`*3?)3```"4H```)^"`#4("5W___`CQ`
M`*1G,'](9%"!`C0M$$0`__\#/"T80P!0@0(T+1!$`/__!#SX?X0T+?!$`%"!
M`C1``*1G+1!$`"VX2`!%9P(\`2-"9#!_8OSG=P(D>!0"`(FK0F0X?V+\74P"
M/']N0F1X$`(`0']B_#(0`CQV5$)D2']B_#T,`CP?+D)D.!$"`%!_8OR`(*)F
M&`"B_S@`XF98?V#\8']@_*A_8*PEL&``.`"B_T``OO](`+#_`````"B#F=\H
M`*3?`(`&-`GX(`,E*,`#`*`"`&``@!HEB(`"6'_#WO@0$0`M$$,``_A"?"L8
M0P`"`6`4`````&!_Q=YZ'Q$`J'_$CBT890!8?\+^\P"`$&!_P_Y``!0D(Q"$
M`BJH40`*$#4"):A``"4P0``X`*+?^(*9WT``I=\)^"`#+2!$`*A_PHXA$%4`
MW/]4%*A_PJX8`+G?)2#@`@GX(`,CH#4"0`"BWRVH50``````0`""*BL`0!0X
M@IG?)8"``B6(H`(`````!P`K:@\`*6H7`"AJ'P`G:B<`)FHO`"5J-P`C:C\`
M(FH``"MN.``B;@@`*6X0`"AN&``G;B``)FXH`"5N,``C;FA_R_X8`+G?)2#@
M`J!_PO[`_Q`F<'_)_GA_R/Z`?\?^B'_&_I!_Q?X)^"`#F'_#_D```BKB_T`0
M0``Q9L#_E":#R8-^`0!D9+@A!`"`&0,`+:BD`B.@@P(X@IG?.`"DWR4P@`)(
M``<D"?@@`R4HH`(H`*3?*(.9WP"`!C0E*,`#"?@@`ZA_U*X`H`(`HO^`'B6(
M@`((@9G?*`"DWPGX(`-(`+#?0`"C9U"!`C0M$$,`__\#/"T80P!8?W'<4($%
M-$``IF?#*")^+2BF``$`1"0M$*(`__\%/"T0H@!@?W?<.0"%*(#_`R2F`*`0
M:']#H$``HV=0@0(T+1!#`/__`SPM$$,`:']"9-B!F=\X``8D(S#$`"4H```)
M^"`#+2!$`/__%#Q``*-G4($"-"T00P`P?X1F+2!$`!@`N=]0@0(T+1!#`"VP
M5``Z1A<`.CP7`#HR%P`Z+A$`.AP1`#H2$0"@?\BBH7_'HJ)_QJ*C?]>BI'_%
MHJ5_PZ*F?\*B"?@@`Z=_T:)``*EG4($(-,A_D68M0`D!+8@1`5"!"#1`?\3>
M2'_#WCA_Q=Y0?\+>,'_&WBU`"0$MH!0!4("'WS-_R)(ZJ@8`.G8$`#IL!``Z
M8@0`.EX#`#I4`P"[?\2BOW_#HCHB`P`ZO`8`.LX%`#K$!0`Z>@4`.O8"`#K\
M`@`Z&@(`LG_5HK!_R**Q?]>BLW_&HK1_V:*U?]BBMG_/HK=_Q:*X?\ZBN7_-
MHKI_S**\?\NBO7_*HKY_Q*+`?]ZBP7_?HL)_PZ+#?\*BL7^49B@`-68#```0
MN&CV9```B)(!`)1F\("9WR4@(`(E.,`"__\&)`$`!20)^"`#`@`Q9O;_L1;_
M_P(\0`"D9U"!`S0M&&0`R']*9%"`B]]0@(??+5!J`$``K&?P@)G?4($#-"T8
M;`!@:FME\&9I9B5`0`(H:>=D__\&)`$`!20E(``"+1!B``GX(`/P?T"@`(.9
MWR4@0`()^"`#4(">WS``HM]P.MYG)2@``B7(P`,?^!$$R&9$9)"`F=]>_!$$
M)2```KW]`!!``*-G`````$``HV=0@0(T+1!#`/__`SSX?V,T'O\`$"VH0P``
M````8'_#WO[^`!`!`&5D"`"TWAW^@!((@IG?"?@@`R4@@`($`$,L&OY@%(B`
MF=]0@(7?_/]"9#B#F=\@::5D"?@@`RT@@@(0_@`0"K""`O__`CPP?U9D4($"
M-"T01@`ML%8`V(&9WS@`U&9```8D(S#$`"4H```)^"`#+2"$`A@`N=\)^"`#
M)2#``C@`P/Y``,#^2`#`_E``P/Y8`,#^8`#`_E'_`!!H`,#^^G]%D)+^I!1H
M@IG?^W]$D)#^@Q0H`*3?_']$D$@``R2+_H,4`````/U_0Y!%``(DA_YB%`(`
M!B0H`+'?)2`@`L;_!20)^"`#4(">WRB#F=\E*(`")2`@`BD`!B0)^"`#<#K>
M9U"`B]]0@(??\("9WV!J:V4E4(`"\&9I9B5`0`(H:>=D__\&)`$`!20)^"`#
M)2```A/^`!``@YG?P(*9WPGX(`,`````</^]9W@`O/\"`!P\+>"9`[#4G&=(
M`++_L(*2WX@`O_]``+'_.`"P_X``OO]P`+?_:`"V_V``M?]8`+3_4`"S__""
M@M\8@9G?``!$CA@`HO\``$+<)`"C9R6(8``(`*/_*`"B_PGX(`,```````!$
MCAB!F=\)^"`#)8!``%"`@]]0@(3?L`!"D#`X>60E*"`",&>$9+$``J(%]Q$$
M$`"Y_P0`0!`Q``,D``!$@-8`@Q``````F("9W]_Z$00`````&(&9WPGX(`,`
M`$2.4("%WT""F=\+``<D`0`&)+AII60)^"`#)2!``$(`0!`8@9G?.("3WQ``
M0]R@PV*.`@!"*#P`0!0H`'3<(``5/#B`E]\EB````0`0)``$M28-```0``06
M)``````X@YG?$`#%W`GX(`,E(,`#*@!`%*##8HX!`!`F*A@"`B8`8!`!`#$F
M&(&9WPGX(`,``$2.<(&9WR4H@`(E.```)3`@`@GX(`,E($``&@!`$"4H0```
M`$;<F,/DW@P`PHSX&!``+1B#`"0050#D_U80``!^W!B!F=\``$2."?@@`P``
MI?\``*7?@(*9WP``I=P"``<D)3````GX(`,E($``.(.9WR4H0``)^"`#)2#`
M`]G_0!"@PV*.H,-BCO__0R1U`'$0`@!"*!B!F=\)^"`#``!$CE"`A=]`@IG?
M`P`')`$`!B3`::5D"?@@`R4@0``1`$`0)8!``!B!F=\)^"`#``!$CA```]Y0
M@(;?``!EW(B"F=\E($``"?@@`\AIQF00``+>``!"W`P`0HR`!4)\B0!`%!B!
MF=\8@9G?"?@@`P``1(Y0@(7?0(*9WP,`!R0!``8DT&FE9`GX(`,E($``$@!`
M$"6`0`!0@(3?$`"YWP@`I=\)^"`#V&:$9```1(XEB$``:`!`$!B!F=\)^"`#
M`````!```]Z(@IG?``!EW"4P(`()^"`#)2!``!B!F=\``$2."?@@`SB`D=\`
M`$2.&(&9WPGX(`,E@$``4("%W_"!F=\!``8DV&FE9`GX(`,E($``4("&WXB"
MF=\E(``"\&G&9`GX(`,E*$``&(&9WPGX(`,``$2.4("$WP@`I=\0`+G?R&:$
M9`GX(`.Q`$"@)8!``#0`0!"HPR+^T(&9W\`!!20)^"`#)2```A$``R0$`$,0
M`0!#)`(`8RQ.`&`0.("#WQ@`HM\H`*/?``!"W$8`8A2(`+_?@`"^WW@`O-]P
M`+??:`"VWV``M=]8`+3?4`"SWT@`LM]``+'?.`"PWP@`X`.0`+UGC/]`%!B!
MF=\!`!`D`````!B!F=\``$2."?@@`P$`$";H@IG?)2B``@GX(`,E($``H,-B
MCBH0`@+U_T`4&(&9WWS_`!```````0!"@"S_0!"8@)G?*/\`$```````````
M.(""WZ"`F=]O^Q$$F,-$W"6`0`#'_T`4J,,B_E"`A-_H@9G?"?@@`_AIA&0`
M````"?@@`P`````X@(/?$``"WIC#8]Q0@)G?``!EW#!`.6</^!$$``!$W)?_
M`!`8@9G?"?@@`P``1(X0``/>H(&9WP``9=P)^"`#)2!``''_`!`8@9G?P(*9
MWPGX(`,`````4("$WYC#8]SH@9G?``!EW"4X0``E,``""?@@`R!JA&3@_[UG
M$`"\_P(`'#PMX)D#X,^<9ZB`F=\(`+'_&`"__P``L/]N^1$$)8B`````1(`>
M`(`0`0!#9"6`0```````+P"".```9(`*@&(`_/^`%`$`8V2(@)G?;_H1!```
M```-`$`0&`"_WPL`(!(````````B@@@`0!!0@(7?0(.9W\!HI60)^"`#)2``
M`@D``A)0@)G?&`"_WQ``O-\(`+'?``"PWP@`X`,@`+UGZ?\`$"6`0``8`+_?
M$`"\WP``L-\E("`""`"QWT`].6<(]P`0(`"]9P```````````````/#_O6<`
M`+S_`@`</"W@F0,`SYQG2(""WPD`0!`(`+__<(*9WPGX(`,``$?<"`"_WP``
MO-\(`.`#$`"]9P````!P@IG?"?@@`R4X```(`+_?``"\WP@`X`,0`+UG````
M`,#_O6<P`+S_`@`</"W@F0.@SIQG$`"R_P``L/_(@)+?T("0W]B`F=\OD%`"
M*`"U_R``M/\8`+/_.`"__P@`L?_[D!(`)9B``"6@H`!L[A$$):C```H`0!(E
MB```````````&=XE,*`")2B``B4@8`()^"`#`0`Q9OG_418(`!!F.`"_WS``
MO-\H`+7?(`"TWQ@`L]\0`++?"`"QWP``L-\(`.`#0`"]9P@`X`,`````$("9
MWR5XX`,)^"`#;``89!"`F=\E>.`#"?@@`VL`&&00@)G?)7C@`PGX(`-I`!AD
M$("9WR5XX`,)^"`#9P`89!"`F=\E>.`#"?@@`V4`&&00@)G?)7C@`PGX(`-D
M`!AD$("9WR5XX`,)^"`#8P`89!"`F=\E>.`#"?@@`V$`&&00@)G?)7C@`PGX
M(`-?`!AD$("9WR5XX`,)^"`#7@`89!"`F=\E>.`#"?@@`UT`&&00@)G?)7C@
M`PGX(`-<`!AD$("9WR5XX`,)^"`#6P`89!"`F=\E>.`#"?@@`UD`&&00@)G?
M)7C@`PGX(`-8`!AD$("9WR5XX`,)^"`#5@`89!"`F=\E>.`#"?@@`U4`&&00
M@)G?)7C@`PGX(`-4`!AD$("9WR5XX`,)^"`#4P`89!"`F=\E>.`#"?@@`U(`
M&&00@)G?)7C@`PGX(`-1`!AD$("9WR5XX`,)^"`#4``89!"`F=\E>.`#"?@@
M`T\`&&00@)G?)7C@`PGX(`-.`!AD$("9WR5XX`,)^"`#30`89!"`F=\E>.`#
M"?@@`TP`&&00@)G?)7C@`PGX(`-+`!AD$("9WR5XX`,)^"`#20`89!"`F=\E
M>.`#"?@@`T<`&&00@)G?)7C@`PGX(`-&`!AD$("9WR5XX`,)^"`#10`89!"`
MF=\E>.`#"?@@`T0`&&00@)G?)7C@`PGX(`-#`!AD$("9WR5XX`,)^"`#0@`8
M9!"`F=\E>.`#"?@@`T$`&&00@)G?)7C@`PGX(`-``!AD$("9WR5XX`,)^"`#
M/P`89!"`F=\E>.`#"?@@`SX`&&00@)G?)7C@`PGX(`,]`!AD$("9WR5XX`,)
M^"`#.P`89!"`F=\E>.`#"?@@`SH`&&00@)G?)7C@`PGX(`,Y`!AD$("9WR5X
MX`,)^"`#.``89!"`F=\E>.`#"?@@`S<`&&00@)G?)7C@`PGX(`,V`!AD$("9
MWR5XX`,)^"`#-0`89!"`F=\E>.`#"?@@`S0`&&00@)G?)7C@`PGX(`,S`!AD
M$("9WR5XX`,)^"`#,@`89!"`F=\E>.`#"?@@`R\`&&00@)G?)7C@`PGX(`,N
M`!AD$("9WR5XX`,)^"`#+0`89!"`F=\E>.`#"?@@`RP`&&00@)G?)7C@`PGX
M(`,J`!AD$("9WR5XX`,)^"`#*``89!"`F=\E>.`#"?@@`R<`&&00@)G?)7C@
M`PGX(`,F`!AD$("9WR5XX`,)^"`#)0`89!"`F=\E>.`#"?@@`R0`&&00@)G?
M)7C@`PGX(`,C`!AD$("9WR5XX`,)^"`#(@`89`````````````````````#P
M_[UG``"\_P(`'#PMX)D#"`"__Q#*G&<(`+_?``"\WP@`X`,0`+UG````````
M```!``(``````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`````
M97AE```````O<')O8R\E:2\E<P``````+@````````!005)?5$5-4```````
M````4$%27U!23T=.04U%`````#H`````````+P`````````E<R5S)7,``%!%
M4DPU3$E"``````````!015),3$E"`%!%4DPU3U!4``````````!015),24\`
M`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1```````4$%27T-,14%.````
M`````%!!4E]$14)51P````````!005)?0T%#2$4`````````4$%27T%21T,`
M`````````%!!4E]!4D=67S````````!005)?1TQ/0D%,7T1%0E5'````````
M``!005)?1TQ/0D%,7U1-4$1)4@````````!005)?5$U01$E2````````4$%2
M7T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``````````%!!4E]#3$5!
M3CT````````Q`````````$Q)0E!!5$@`3$1?3$E"4D%265]0051(`$Q)0E)!
M4EE?4$%42`````!$64Q$7TQ)0E)!4EE?4$%42`````````!32$Q)0E]0051(
M````````55-%4@````!365-414T``"]T;7``````5$U01$E2``!414U01$E2
M`%1%35``````5$U0``````!54T523D%-10``````````)3`R>`````!P87(M
M`````"5S)7,E<R5S```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````<&%R;```
M```N<&%R`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E
M<W1E;7`M)74M)74E<P``````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@```````$%21U8`````&`````````!P97)L`````#``
M````````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP,S8```!5;F%B;&4@
M=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@``````````)7,````````M90```````"TM````````979A;"`G
M97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@
M;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L
M.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@
M:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@
M)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D[
M"F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL
M93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL
M:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P
M87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@
M1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC
M;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@]
M,3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP
M)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE
M97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE
M;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C
M;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC
M;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^
M9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?
M<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A
M;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%21U8@/2!M87`@)$5.5GLB4$%2
M7T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*)#`@/2`D
M14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@*&ME>7,@)45.5BD@>PID
M96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PI]"GT*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M
M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D
M<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&
M2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@
M<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P
M('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0[
M"B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S
M970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?
M1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L
M("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64[
M"GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I
M;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H
M:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<
M120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H
M+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[
M8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A
M;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN
M9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D
M14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@
M/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI
M;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%2
M1U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E
M('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H
M:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T
M;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R
M(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H
M)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q
M("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@
M>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G
M9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A
M(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D
M("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I
M.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@
M)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E
M96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I
M;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE
M<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]
M("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*
M9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@
M)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@
M/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME
M>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V
M86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@
M+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID
M;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C
M:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@
M/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD
M9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D[
M"B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T
M+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@
M+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD
M9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB
M97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI]
M(&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@
M/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@
M)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M
M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@
M;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q
M=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*
M<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R
M<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG
M.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G
M.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I
M.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y
M<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92![
M"FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA
M;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO
M<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*
M8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T
M.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG
M+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A
M(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F
M:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N
M9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E
M(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``````%]?14Y6
M7U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@``````````!P97)L>'-I+F,`
M```````````````````O;&EB-C0O;&0N<V\N,0````````0````0`````0``
M`$=.50```````P````(`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````8(````````*@?````
M````````````````````````````````````_____P```````````````(!J
M````````````````````````````````````````````````````````````
M@-`;````````D&$````````X8@```````````@``````.+`!``````!XLP$`
M```````````````````!``````!@00```````(!;````````.$(````````@
M2P```````%A#````````:$H```````!X2P```````+A'````````:$T`````
M```P1@```````#!A````````(+`!``````!08````````/"O`0``````Z*\!
M``````"0&P``````````````````````````````9@```````/!E````````
MX&4```````#090```````,!E````````L&4```````"@90``````````````
M````D&4``````````````````(!E````````<&4```````!@90```````%!E
M`````````````````````````````$!E````````,&4````````@90``````
M`!!E`````````&4```````#P9````````.!D````````T&0```````#`9```
M`````+!D``````````````````"@9````````)!D````````@&0```````!P
M9````````&!D````````4&0```````!`9````````#!D````````(&0`````
M```09`````````!D``````````````````#P8P``````````````````X&,`
M``````#08P```````,!C````````L&,```````"@8P```````)!C````````
M@&,```````!P8P```````&!C````````4&,```````!`8P```````#!C````
M```````````````@8P```````!!C````````````````````8P```````/!B
M````````X&(```````#08@```````,!B``````````````````"P8@``````
M````````````H&(```````"08@```````(!B``````````````````!P8@``
M````````````````8&(``````````````````%!B````````0&(```````!X
MLP$``````$=#0SH@*$1E8FEA;B`V+C,N,"TR*2`V+C,N,"`R,#$V,3(R.0!'
M0T,Z("A$96)I86X@-BXR+C$M-2D@-BXR+C$@,C`Q-C$Q,C0```"`(``````/
MD/C___\``````````,`"```=````'P```#`X`````'^0^/___P``````````
M4````!T````?````B#D`````'Y#X____``````````!0````'0```!\```!P
M.@````#_D/C___\``````````&`````=````'P```$`]`````/^0^/___P``
M````````,`$``!T````?````6#\``````Y#X____```````````@````'0``
M`!\````P0``````?D/C___\``````````%`0```=````'P```&!!``````"0
M^/___P``````````$````!T````?````N$$``````9#X____```````````@
M````'0```!\````X0@`````'D/C___\``````````&`@```=````'P```$!#
M`````````````````````````````!T````?````6$,`````_]#X____````
M``````"`$```'0```!\`````1@`````````````````````````````=````
M'P```#!&``````.0^/___P``````````(````!T````?````N$<`````_Y#X
M____``````````"0````'0```!\```!H2@`````#D/C___\``````````#``
M```=````'P```"!+``````"0^/___P``````````$````!T````?````>$L`
M````_]#X____``````````#0````'0```!\```!H30````#_T/C___\`````
M`````/"!```=````'P```(!;`````/_0^/___P``````````D````!T````?
M````4&```````Y#X____```````````@````'0```!\```#0&P`````_D/C_
M__\``````````'`````=````'P```#!A``````"0^/___P``````````$```
M`!T````?````D&$`````/Y#X____``````````!`````'0```!\````X8@``
M```````````````````````````=````'P```$$/````9VYU``$'````!`$`
M+G-H<W1R=&%B`"Y-25!3+F%B:69L86=S`"Y-25!3+F]P=&EO;G,`+FYO=&4N
M9VYU+F)U:6QD+6ED`"YD>6YA;6EC`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N
M9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+FEN:70`+G1E
M>'0`+DU)4%,N<W1U8G,`+F9I;FD`+G)O9&%T80`N:6YT97)P`"YE:%]F<F%M
M90`N;F]T92Y!0DDM=&%G`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`
M+F1A=&$`+G)L9%]M87``+F=O=``N<V1A=&$`+F)S<P`N8V]M;65N=``N<&1R
M`"YG;G4N871T<FEB=71E<P``````````````````````````````````````
M``````````````````````````````````````````````````````L````J
M``!P`@````````!P`@```````'`"````````&`````````````````````@`
M````````&``````````:````#0``<`(```@`````B`(```````"(`@``````
M`)`!```````````````````(``````````$`````````*`````<````"````
M`````!@$````````&`0````````D````````````````````!```````````
M`````````#L````&`````@````````!`!````````$`$````````H`(`````
M```'``````````@`````````$`````````!$````!0````(`````````X`8`
M``````#@!@```````$`#````````!@`````````(``````````0`````````
M2@````L````"`````````"`*````````(`H````````X"@````````<````"
M````"``````````8`````````%(````#`````@````````!8%````````%@4
M````````5P4```````````````````$```````````````````!:````____
M;P(`````````L!D```````"P&0```````-H`````````!@`````````"````
M``````(`````````9P```/[__V\"`````````)`:````````D!H```````"P
M``````````<````#````"````````````````````'8````)`````@``````
M``!`&P```````$`;````````4``````````&``````````@`````````$```
M``````!_`````0````8`````````D!L```````"0&P```````$``````````
M```````````$````````````````````A0````$````&`````````-`;````
M````T!L```````!P1@``````````````````$````````````````````(L`
M```!````!@````````!`8@```````$!B````````X`,`````````````````
M``@```````````````````"7`````0````8`````````(&8````````@9@``
M`````"@````````````````````$````````````````````G0````$````"
M`````````%!F````````4&8```````!P00``````````````````$```````
M`````````````*4````!`````@````````#`IP```````,"G````````#P``
M``````````````````$```````````````````"M`````0````(`````````
MT*<```````#0IP````````0````````````````````$````````````````
M````MP````<````"`````````-2G````````U*<````````@````````````
M````````!````````````````````,4````.`````P````````#HKP$`````
M`.BO````````"`````````````````````@`````````"`````````#1````
M#P````,`````````\*\!``````#PKP````````@````````````````````(
M``````````@`````````W0````$````#`````````/BO`0``````^*\`````
M```(````````````````````"````````````````````.(````!`````P``
M````````L`$```````"P````````,````````````````````!``````````
M``````````#H`````0````,`````````,+`!```````PL`````````@`````
M```````````````(````````````````````\0````$````#```0`````$"P
M`0``````0+`````````X`P``````````````````$``````````(````````
M`/8````!`````P``$`````!XLP$``````'BS````````"```````````````
M``````@```````````````````#]````"`````,`````````@+,!``````"`
MLP```````$`0```````````````````0`````````````````````@$```$`
M```P````````````````````@+,```````!*`````````````````````0``
M```````!``````````L!```!`````````````````````````,RS````````
M(`,```````````````````0````````````````````0`0``]?__;P``````
M``````````````#LM@```````!`````````````````````!````````````
M`````````0````,`````````````````````````_+8````````@`0``````
9`````````````0``````````````````````
